package com.srs.routine.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.routine.domain.SrsAttachResource;

/**
 * 附件资源Service接口
 *
 * @author srs
 * @date 2024-05-18
 */
public interface ISrsAttachResourceService extends IService<SrsAttachResource> {
    /**
     * 查询附件资源
     *
     * @param resId 附件资源主键
     * @return 附件资源
     */
    public SrsAttachResource selectSrsAttachResourceByResId(Long resId);

    /**
     * 查询附件资源列表
     *
     * @param srsAttachResource 附件资源
     * @return 附件资源集合
     */
    List<SrsAttachResource> selectSrsAttachResourceList(SrsAttachResource srsAttachResource);

    /**
     * 新增附件资源
     *
     * @param srsAttachResource 附件资源
     * @return 结果
     */
    int insertSrsAttachResource(SrsAttachResource srsAttachResource);

    /**
     * 修改附件资源
     *
     * @param srsAttachResource 附件资源
     * @return 结果
     */
    int updateSrsAttachResource(SrsAttachResource srsAttachResource);

    /**
     * 批量删除附件资源
     *
     * @param resIds 需要删除的附件资源主键集合
     * @return 结果
     */
    int deleteSrsAttachResourceByResIds(Long[] resIds);

    /**
     * 删除附件资源信息
     *
     * @param resId 附件资源主键
     * @return 结果
     */
    int deleteSrsAttachResourceByResId(Long resId);
}
